You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ibatis.apache.org by ro...@apache.org on 2005/05/10 05:09:48 UTC

svn commit: r169402 - /incubator/ibatis/trunk/cs/mapper/IBatisNet.Common /incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test /incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Domain /incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/ODP /incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/OracleClient /incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Commands /incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration /incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Alias /incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Cache /incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ParamaterMapping /incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ResultMapping /incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements /incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements

Author: roberto
Date: Mon May  9 20:09:47 2005
New Revision: 169402

URL: http://svn.apache.org/viewcvs?rev=169402&view=rev
Log:
~Updated C# DataMapper for attribute spelling 
~Updated C# DataMapper NUnit files for TypeHandlers namespace name change
+Adding OneZeroBoolTypeHandlerCallback.cs to DataMapper.Test project file

Modified:
    incubator/ibatis/trunk/cs/mapper/IBatisNet.Common/DataSource.cs
    incubator/ibatis/trunk/cs/mapper/IBatisNet.Common/Provider.cs
    incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Domain/OneZeroBoolTypeHandlerCallback.cs
    incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Domain/YesNoBoolTypeHandlerCallback.cs
    incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/IBatisNet.DataMapper.Test.csproj
    incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/ODP/Other.xml
    incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/ODP/ResultClass.xml
    incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/OracleClient/Other.xml
    incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/OracleClient/ResultClass.xml
    incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Commands/DefaultPreparedCommand.cs
    incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Commands/EmbedParamsPreparedCommand.cs
    incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Alias/TypeAlias.cs
    incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Cache/CacheModel.cs
    incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/DomSqlMapBuilder.cs
    incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ParamaterMapping/ParameterMap.cs
    incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ParamaterMapping/ParameterProperty.cs
    incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ResultMapping/ResultMap.cs
    incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ResultMapping/ResultProperty.cs
    incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/Generate.cs
    incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/PreparedStatementFactory.cs
    incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/Procedure.cs
    incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/Statement.cs
    incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/MappedStatement.cs

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.Common/DataSource.cs
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.Common/DataSource.cs?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.Common/DataSource.cs (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.Common/DataSource.cs Mon May  9 20:09:47 2005
@@ -61,7 +61,7 @@
 			set
 			{
 				if ((value == null) || (value.Length < 1))
-					throw new ArgumentNullException("The connectionString attribut is mandatory in the data source " + _name);
+					throw new ArgumentNullException("The connectionString attribute is mandatory in the data source " + _name);
 
 				_connectionString = value;
 			}
@@ -77,7 +77,7 @@
 			set 
 			{ 
 				if ((value == null) || (value.Length < 1))
-					throw new ArgumentNullException("The name attribut is mandatory in the data source.");
+					throw new ArgumentNullException("The name attribute is mandatory in the data source.");
 
 				_name = value; 
 			}

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.Common/Provider.cs
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.Common/Provider.cs?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.Common/Provider.cs (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.Common/Provider.cs Mon May  9 20:09:47 2005
@@ -169,7 +169,7 @@
 			set
 			{
 				if ((value == null) || (value.Length < 1))
-					throw new ArgumentNullException("The connectionClass attribut is mandatory in the provider " + _name);
+					throw new ArgumentNullException("The connectionClass attribute is mandatory in the provider " + _name);
 				_connectionClass = value;
 			}
 		}
@@ -288,7 +288,7 @@
 			set
 			{
 				if ((value == null) || (value.Length < 1))
-					throw new ArgumentNullException("The commandClass attribut is mandatory in the provider " + _name);
+					throw new ArgumentNullException("The commandClass attribute is mandatory in the provider " + _name);
 				_commandClass = value;
 			}
 		}
@@ -307,7 +307,7 @@
 			set
 			{
 				if ((value == null) || (value.Length < 1))
-					throw new ArgumentNullException("The parameterClass attribut is mandatory in the provider " + _name);
+					throw new ArgumentNullException("The parameterClass attribute is mandatory in the provider " + _name);
 				_dataParameter = value;
 			}
 		}
@@ -326,7 +326,7 @@
 			set
 			{
 				if ((value == null) || (value.Length < 1))
-					throw new ArgumentNullException("The parameterDbTypeClass attribut is mandatory in the provider " + _name);
+					throw new ArgumentNullException("The parameterDbTypeClass attribute is mandatory in the provider " + _name);
 				_parameterDbTypeClass = value;
 			}
 		}
@@ -346,7 +346,7 @@
 			set
 			{
 				if ((value == null) || (value.Length < 1))
-					throw new ArgumentNullException("The parameterDbTypeProperty attribut is mandatory in the provider " + _name);
+					throw new ArgumentNullException("The parameterDbTypeProperty attribute is mandatory in the provider " + _name);
 				_parameterDbTypeProperty = value;
 			}
 		}
@@ -364,7 +364,7 @@
 			set
 			{
 				if ((value == null) || (value.Length < 1))
-					throw new ArgumentNullException("The dataAdapterClass attribut is mandatory in the provider " + _name);
+					throw new ArgumentNullException("The dataAdapterClass attribute is mandatory in the provider " + _name);
 				_dataAdapterClass = value;
 			}
 		}
@@ -384,7 +384,7 @@
 			set
 			{
 				if ((value == null) || (value.Length < 1))
-					throw new ArgumentNullException("The commandBuilderClass attribut is mandatory in the provider " + _name);
+					throw new ArgumentNullException("The commandBuilderClass attribute is mandatory in the provider " + _name);
 				_commandBuilderClass = value;
 			}
 		}
@@ -400,7 +400,7 @@
 			set 
 			{ 
 				if ((value == null) || (value.Length < 1))
-					throw new ArgumentNullException("The name attribut is mandatory in the provider.");
+					throw new ArgumentNullException("The name attribute is mandatory in the provider.");
 
 				_name = value; 			
 			}
@@ -429,7 +429,7 @@
 				if ((value == null) || (value.Length < 1))
 				{
 					_parameterPrefix = ""; 
-					//throw new ArgumentNullException("The parameterPrefix attribut is mandatory in the provider " + _name);
+					//throw new ArgumentNullException("The parameterPrefix attribute is mandatory in the provider " + _name);
 				}
 				else
 				{

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Domain/OneZeroBoolTypeHandlerCallback.cs
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Domain/OneZeroBoolTypeHandlerCallback.cs?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Domain/OneZeroBoolTypeHandlerCallback.cs (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Domain/OneZeroBoolTypeHandlerCallback.cs Mon May  9 20:09:47 2005
@@ -1,6 +1,6 @@
 using System;
 
-using IBatisNet.DataMapper.TypesHandler;
+using IBatisNet.DataMapper.TypeHandlers;
 
 namespace IBatisNet.DataMapper.Test.Domain
 {

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Domain/YesNoBoolTypeHandlerCallback.cs
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Domain/YesNoBoolTypeHandlerCallback.cs?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Domain/YesNoBoolTypeHandlerCallback.cs (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Domain/YesNoBoolTypeHandlerCallback.cs Mon May  9 20:09:47 2005
@@ -1,6 +1,6 @@
 using System;
 
-using IBatisNet.DataMapper.TypesHandler;
+using IBatisNet.DataMapper.TypeHandlers;
 
 namespace IBatisNet.DataMapper.Test.Domain
 {

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/IBatisNet.DataMapper.Test.csproj
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/IBatisNet.DataMapper.Test.csproj?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/IBatisNet.DataMapper.Test.csproj (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/IBatisNet.DataMapper.Test.csproj Mon May  9 20:09:47 2005
@@ -243,6 +243,11 @@
                     BuildAction = "Compile"
                 />
                 <File
+                    RelPath = "Domain\OneZeroBoolTypeHandlerCallback.cs"
+                    SubType = "Code"
+                    BuildAction = "Compile"
+                />
+                <File
                     RelPath = "Domain\Order.cs"
                     SubType = "Code"
                     BuildAction = "Compile"

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/ODP/Other.xml
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/ODP/Other.xml?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/ODP/Other.xml (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/ODP/Other.xml Mon May  9 20:09:47 2005
@@ -24,8 +24,8 @@
 		Specified method is not supported.
 		
 		at Oracle.DataAccess.Client.OracleDataReader.GetBoolean(Int32 i)
-		at IBatisNet.DataMapper.TypesHandler.BooleanTypeHandler.GetValueByName(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\BooleanTypeHandler.cs:line 61
-		at IBatisNet.DataMapper.TypesHandler.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\BaseTypeHandler.cs:line 54
+		at IBatisNet.DataMapper.TypeHandlers.BooleanTypeHandler.GetValueByName(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\BooleanTypeHandler.cs:line 61
+		at IBatisNet.DataMapper.TypeHandlers.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\BaseTypeHandler.cs:line 54
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.SetObjectProperty(RequestScope request, ResultMap resultMap, ResultProperty mapping, Object& target, IDataReader reader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 1076
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.ApplyResultMap(RequestScope request, IDataReader reader, Object resultObject) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 393
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.RunQueryForList(RequestScope request, IDalSession session, Object parameterObject, Int32 skipResults, Int32 maxResults, RowDelegate rowDelegate) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 726

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/ODP/ResultClass.xml
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/ODP/ResultClass.xml?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/ODP/ResultClass.xml (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/ODP/ResultClass.xml Mon May  9 20:09:47 2005
@@ -1,4 +1,4 @@
-<?xml version="1.0" encoding="UTF-8" ?>
+<?xml version="1.0" encoding="UTF-8" ?>
 
 <sqlMap namespace="ResultClass" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
 	xsi:noNamespaceSchemaLocation="SqlMap.xsd">
@@ -8,8 +8,8 @@
 		Using ODP.NET 10.1
 		Throws System.NotSupportedException
 		at Oracle.DataAccess.Client.OracleDataReader.GetBoolean(Int32 i)
-		at IBatisNet.DataMapper.TypesHandler.BooleanTypeHandler.GetValueByIndex(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\BooleanTypeHandler.cs:line 69
-		at IBatisNet.DataMapper.TypesHandler.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\BaseTypeHandler.cs:line 58
+		at IBatisNet.DataMapper.TypeHandlers.BooleanTypeHandler.GetValueByIndex(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\BooleanTypeHandler.cs:line 69
+		at IBatisNet.DataMapper.TypeHandlers.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\BaseTypeHandler.cs:line 58
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.SetObjectProperty(RequestScope request, ResultMap resultMap, ResultProperty mapping, Object& target, IDataReader reader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 1059
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.ApplyResultMap(RequestScope request, IDataReader reader, Object resultObject) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 403
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.RunQueryForObject(RequestScope request, IDalSession session, Object parameterObject, Object resultObject) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 562
@@ -28,8 +28,8 @@
 		Using ODP.NET 10.1
 		Throws System.InvalidCastException
 		at Oracle.DataAccess.Client.OracleDataReader.GetByte(Int32 i)
-		at IBatisNet.DataMapper.TypesHandler.ByteTypeHandler.GetValueByIndex(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\ByteTypeHandler.cs:line 69
-		at IBatisNet.DataMapper.TypesHandler.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\BaseTypeHandler.cs:line 58
+		at IBatisNet.DataMapper.TypeHandlers.ByteTypeHandler.GetValueByIndex(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\ByteTypeHandler.cs:line 69
+		at IBatisNet.DataMapper.TypeHandlers.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\BaseTypeHandler.cs:line 58
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.SetObjectProperty(RequestScope request, ResultMap resultMap, ResultProperty mapping, Object& target, IDataReader reader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 1059
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.ApplyResultMap(RequestScope request, IDataReader reader, Object resultObject) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 403
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.RunQueryForObject(RequestScope request, IDalSession session, Object parameterObject, Object resultObject) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 562
@@ -66,8 +66,8 @@
 		Using ODP.NET 10.1
 		Throws System.InvalidCastException
 		at Oracle.DataAccess.Client.OracleDataReader.GetDouble(Int32 i)
-		at IBatisNet.DataMapper.TypesHandler.DoubleTypeHandler.GetValueByIndex(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\DoubleTypeHandler.cs:line 69
-		at IBatisNet.DataMapper.TypesHandler.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\BaseTypeHandler.cs:line 58
+		at IBatisNet.DataMapper.TypeHandlers.DoubleTypeHandler.GetValueByIndex(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\DoubleTypeHandler.cs:line 69
+		at IBatisNet.DataMapper.TypeHandlers.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\BaseTypeHandler.cs:line 58
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.SetObjectProperty(RequestScope request, ResultMap resultMap, ResultProperty mapping, Object& target, IDataReader reader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 1059
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.ApplyResultMap(RequestScope request, IDataReader reader, Object resultObject) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 403
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.RunQueryForObject(RequestScope request, IDalSession session, Object parameterObject, Object resultObject) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 562
@@ -86,8 +86,8 @@
 		Using ODP.NET 10.1
 		Throws System.NotSupportedException
 		at Oracle.DataAccess.Client.OracleDataReader.GetGuid(Int32 i)
-		at IBatisNet.DataMapper.TypesHandler.GuidTypeHandler.GetValueByIndex(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\GuidTypeHandler.cs:line 68
-		at IBatisNet.DataMapper.TypesHandler.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\BaseTypeHandler.cs:line 58
+		at IBatisNet.DataMapper.TypeHandlers.GuidTypeHandler.GetValueByIndex(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\GuidTypeHandler.cs:line 68
+		at IBatisNet.DataMapper.TypeHandlers.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\BaseTypeHandler.cs:line 58
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.SetObjectProperty(RequestScope request, ResultMap resultMap, ResultProperty mapping, Object& target, IDataReader reader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 1059
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.ApplyResultMap(RequestScope request, IDataReader reader, Object resultObject) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 403
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.RunQueryForObject(RequestScope request, IDalSession session, Object parameterObject, Object resultObject) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 562
@@ -124,8 +124,8 @@
 		Using ODP.NET 10.1
 		Throws System.InvalidCastException
 		at Oracle.DataAccess.Client.OracleDataReader.GetFloat(Int32 i)
-		at IBatisNet.DataMapper.TypesHandler.SingleTypeHandler.GetValueByIndex(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\SingleTypeHandler.cs:line 75
-		at IBatisNet.DataMapper.TypesHandler.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\BaseTypeHandler.cs:line 58
+		at IBatisNet.DataMapper.TypeHandlers.SingleTypeHandler.GetValueByIndex(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\SingleTypeHandler.cs:line 75
+		at IBatisNet.DataMapper.TypeHandlers.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\BaseTypeHandler.cs:line 58
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.SetObjectProperty(RequestScope request, ResultMap resultMap, ResultProperty mapping, Object& target, IDataReader reader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 1059
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.ApplyResultMap(RequestScope request, IDataReader reader, Object resultObject) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 403
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.RunQueryForObject(RequestScope request, IDalSession session, Object parameterObject, Object resultObject) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 562

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/OracleClient/Other.xml
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/OracleClient/Other.xml?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/OracleClient/Other.xml (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/OracleClient/Other.xml Mon May  9 20:09:47 2005
@@ -1,4 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
+<?xml version="1.0" encoding="utf-8"?>
 <sqlMap namespace="Other" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
 		xsi:noNamespaceSchemaLocation="SqlMap.xsd">
 	
@@ -24,8 +24,8 @@
 		Specified method is not supported.
 		
 	    at System.Data.OracleClient.OracleDataReader.GetBoolean(Int32 i)
-		at IBatisNet.DataMapper.TypesHandler.BooleanTypeHandler.GetValueByName(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\BooleanTypeHandler.cs:line 61
-		at IBatisNet.DataMapper.TypesHandler.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\BaseTypeHandler.cs:line 54
+		at IBatisNet.DataMapper.TypeHandlers.BooleanTypeHandler.GetValueByName(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\BooleanTypeHandler.cs:line 61
+		at IBatisNet.DataMapper.TypeHandlers.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\BaseTypeHandler.cs:line 54
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.SetObjectProperty(RequestScope request, ResultMap resultMap, ResultProperty mapping, Object& target, IDataReader reader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 1076
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.ApplyResultMap(RequestScope request, IDataReader reader, Object resultObject) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 393
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.RunQueryForObject(RequestScope request, IDalSession session, Object parameterObject, Object resultObject) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 575
@@ -59,8 +59,8 @@
 		Specified method is not supported.
 		
 		at System.Data.OracleClient.OracleDataReader.GetBoolean(Int32 i)
-		at IBatisNet.DataMapper.TypesHandler.BooleanTypeHandler.GetValueByName(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\BooleanTypeHandler.cs:line 61
-		at IBatisNet.DataMapper.TypesHandler.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\BaseTypeHandler.cs:line 54
+		at IBatisNet.DataMapper.TypeHandlers.BooleanTypeHandler.GetValueByName(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\BooleanTypeHandler.cs:line 61
+		at IBatisNet.DataMapper.TypeHandlers.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\BaseTypeHandler.cs:line 54
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.SetObjectProperty(RequestScope request, ResultMap resultMap, ResultProperty mapping, Object& target, IDataReader reader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 1076
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.ApplyResultMap(RequestScope request, IDataReader reader, Object resultObject) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 393
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.RunQueryForList(RequestScope request, IDalSession session, Object parameterObject, Int32 skipResults, Int32 maxResults, RowDelegate rowDelegate) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 726

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/OracleClient/ResultClass.xml
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/OracleClient/ResultClass.xml?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/OracleClient/ResultClass.xml (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper.Test/Maps/Oracle/OracleClient/ResultClass.xml Mon May  9 20:09:47 2005
@@ -7,8 +7,8 @@
 		<!--
 		Throws System.NotSupportedException
 		at System.Data.OracleClient.OracleDataReader.GetBoolean(Int32 i)
-		at IBatisNet.DataMapper.TypesHandler.BooleanTypeHandler.GetValueByIndex(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\BooleanTypeHandler.cs:line 69
-		at IBatisNet.DataMapper.TypesHandler.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\BaseTypeHandler.cs:line 58
+		at IBatisNet.DataMapper.TypeHandlers.BooleanTypeHandler.GetValueByIndex(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\BooleanTypeHandler.cs:line 69
+		at IBatisNet.DataMapper.TypeHandlers.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\BaseTypeHandler.cs:line 58
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.SetObjectProperty(RequestScope request, ResultMap resultMap, ResultProperty mapping, Object& target, IDataReader reader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 1059
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.ApplyResultMap(RequestScope request, IDataReader reader, Object resultObject) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 403
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.RunQueryForObject(RequestScope request, IDalSession session, Object parameterObject, Object resultObject) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 562
@@ -26,8 +26,8 @@
 		<!--
 		Throws System.NotSupportedException
 		at System.Data.OracleClient.OracleDataReader.GetByte(Int32 i)
-		at IBatisNet.DataMapper.TypesHandler.ByteTypeHandler.GetValueByIndex(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\ByteTypeHandler.cs:line 69
-		at IBatisNet.DataMapper.TypesHandler.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\BaseTypeHandler.cs:line 58
+		at IBatisNet.DataMapper.TypeHandlers.ByteTypeHandler.GetValueByIndex(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\ByteTypeHandler.cs:line 69
+		at IBatisNet.DataMapper.TypeHandlers.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\BaseTypeHandler.cs:line 58
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.SetObjectProperty(RequestScope request, ResultMap resultMap, ResultProperty mapping, Object& target, IDataReader reader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 1059
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.ApplyResultMap(RequestScope request, IDataReader reader, Object resultObject) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 403
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.RunQueryForObject(RequestScope request, IDalSession session, Object parameterObject, Object resultObject) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 562
@@ -69,8 +69,8 @@
 		<!--
 		Throws System.NotSupportedException
         at System.Data.OracleClient.OracleDataReader.GetGuid(Int32 i)
-		at IBatisNet.DataMapper.TypesHandler.GuidTypeHandler.GetValueByIndex(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\GuidTypeHandler.cs:line 68
-		at IBatisNet.DataMapper.TypesHandler.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypesHandler\BaseTypeHandler.cs:line 58
+		at IBatisNet.DataMapper.TypeHandlers.GuidTypeHandler.GetValueByIndex(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\GuidTypeHandler.cs:line 68
+		at IBatisNet.DataMapper.TypeHandlers.BaseTypeHandler.GetDataBaseValue(ResultProperty mapping, IDataReader dataReader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\TypeHandlers\BaseTypeHandler.cs:line 58
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.SetObjectProperty(RequestScope request, ResultMap resultMap, ResultProperty mapping, Object& target, IDataReader reader) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 1059
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.ApplyResultMap(RequestScope request, IDataReader reader, Object resultObject) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 403
 		at IBatisNet.DataMapper.MappedStatements.MappedStatement.RunQueryForObject(RequestScope request, IDalSession session, Object parameterObject, Object resultObject) in C:\projects\ibatis\asf\trunk\cs\mapper\IBatisNet.DataMapper\MappedStatements\MappedStatement.cs:line 562

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Commands/DefaultPreparedCommand.cs
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Commands/DefaultPreparedCommand.cs?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Commands/DefaultPreparedCommand.cs (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Commands/DefaultPreparedCommand.cs Mon May  9 20:09:47 2005
@@ -160,7 +160,7 @@
 					// to indicate the mapping order of the properties to the columns
 					if (request.ParameterMap == null) // Inline Parameters
 					{
-						throw new DataMapperException("A procedure statement tag must alway have a parameterMap attribut, which is not the case for the procedure '"+statement.Id+"'."); 
+						throw new DataMapperException("A procedure statement tag must alway have a parameterMap attribute, which is not the case for the procedure '"+statement.Id+"'."); 
 					}
 					else // Parameters via ParameterMap
 					{

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Commands/EmbedParamsPreparedCommand.cs
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Commands/EmbedParamsPreparedCommand.cs?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Commands/EmbedParamsPreparedCommand.cs (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Commands/EmbedParamsPreparedCommand.cs Mon May  9 20:09:47 2005
@@ -89,7 +89,7 @@
 					// to indicate the mapping order of the properties to the columns
 					if (request.ParameterMap == null) // Inline Parameters
 					{
-						throw new DataMapperException("A procedure statement tag must alway have a parameterMap attribut, which is not the case for the procedure '" + statement.Id + "'.");
+						throw new DataMapperException("A procedure statement tag must alway have a parameterMap attribute, which is not the case for the procedure '" + statement.Id + "'.");
 					}
 					else // Parameters via ParameterMap
 					{

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Alias/TypeAlias.cs
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Alias/TypeAlias.cs?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Alias/TypeAlias.cs (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Alias/TypeAlias.cs Mon May  9 20:09:47 2005
@@ -67,7 +67,7 @@
 			{ 
 				if ((value == null) || (value.Length < 1))
 				{
-					throw new ArgumentNullException("The name attribut is mandatory in the typeAlias ");
+					throw new ArgumentNullException("The name attribute is mandatory in the typeAlias ");
 				}
 				_name = value; 
 			}
@@ -96,7 +96,7 @@
 			{ 
 				if ((value == null) || (value.Length < 1))
 				{
-					throw new ArgumentNullException("The class attribut is mandatory in the typeAlias " + _name);
+					throw new ArgumentNullException("The class attribute is mandatory in the typeAlias " + _name);
 				}
 				_className = value; 
 			}

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Cache/CacheModel.cs
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Cache/CacheModel.cs?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Cache/CacheModel.cs (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Cache/CacheModel.cs Mon May  9 20:09:47 2005
@@ -93,7 +93,7 @@
 			set 
 			{ 
 				if ((value == null) || (value.Length < 1))
-					throw new ArgumentNullException("The id attribut is mandatory in a cacheModel tag.");
+					throw new ArgumentNullException("The id attribute is mandatory in a cacheModel tag.");
 
 				_id = value; 
 			}
@@ -109,7 +109,7 @@
 			set 
 			{ 
 				if ((value == null) || (value.Length < 1))
-					throw new ArgumentNullException("The implementation attribut is mandatory in a cacheModel tag.");
+					throw new ArgumentNullException("The implementation attribute is mandatory in a cacheModel tag.");
 
 				_implementation = value; 
 			}

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/DomSqlMapBuilder.cs
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/DomSqlMapBuilder.cs?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ParamaterMapping/ParameterMap.cs (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ParamaterMapping/ParameterMap.cs Mon May  9 20:09:47 2005
@@ -76,7 +76,7 @@
 			set 
 			{ 
 				if ((value == null) || (value.Length < 1))
-					throw new ArgumentNullException("The id attribut is mandatory in a ParameterMap tag.");
+					throw new ArgumentNullException("The id attribute is mandatory in a ParameterMap tag.");
 
 				_id = value; 
 			}

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ParamaterMapping/ParameterProperty.cs
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ParamaterMapping/ParameterProperty.cs?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ResultMapping/ResultMap.cs (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ResultMapping/ResultMap.cs Mon May  9 20:09:47 2005
@@ -119,7 +119,7 @@
 			set 
 			{ 
 				if ((value == null) || (value.Length < 1))
-					throw new ArgumentNullException("The id attribut is mandatory in a ResultMap tag.");
+					throw new ArgumentNullException("The id attribute is mandatory in a ResultMap tag.");
 
 				_id = value; 
 			}
@@ -156,7 +156,7 @@
 			set 
 			{ 
 				if ((value == null) || (value.Length < 1))
-					throw new ArgumentNullException("The class attribut is mandatory in a ResultMap tag.");
+					throw new ArgumentNullException("The class attribute is mandatory in a ResultMap tag.");
 
 				_className = value; 
 			}

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ResultMapping/ResultProperty.cs
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ResultMapping/ResultProperty.cs?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ResultMapping/ResultProperty.cs (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ResultMapping/ResultProperty.cs Mon May  9 20:09:47 2005
@@ -191,7 +191,7 @@
 			set 
 			{ 
 				if ((value == null) || (value.Length < 1))
-					throw new ArgumentNullException("The property attribut is mandatory in a result property.");
+					throw new ArgumentNullException("The property attribute is mandatory in a result property.");
 
 				_property = value; 
 			}

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/Generate.cs
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/Generate.cs?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/Generate.cs (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/Generate.cs Mon May  9 20:09:47 2005
@@ -62,7 +62,7 @@
 		}
 
 		/// <summary>
-		/// The by attribut is used to generate the where clause.
+		/// The by attribute is used to generate the where clause.
 		/// </summary>
 		/// <remarks>The by="" attribute can support multiple colums.</remarks>
 		/// <example> 

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/PreparedStatementFactory.cs
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/PreparedStatementFactory.cs?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/Procedure.cs (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/Procedure.cs Mon May  9 20:09:47 2005
@@ -85,7 +85,7 @@
 			base.Initialize( configurationScope );
 			if (this.ParameterMap == null)
 			{
-				throw new ConfigurationException("The parameterMap attribut is required in the procedure tag named '"+ this.Id +"'.");
+				throw new ConfigurationException("The parameterMap attribute is required in the procedure tag named '"+ this.Id +"'.");
 			}
 		}
 		#endregion

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/Statement.cs
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/Statement.cs?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/Statement.cs (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/Statement.cs Mon May  9 20:09:47 2005
@@ -206,7 +206,7 @@
 			set 
 			{ 
 				if ((value == null) || (value.Length < 1))
-					throw new DataMapperException("The id attribut is required in a statement tag.");
+					throw new DataMapperException("The id attribute is required in a statement tag.");
 
 				_id= value; 
 			}

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/MappedStatement.cs
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/MappedStatement.cs?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/MappedStatement.cs (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/MappedStatements/MappedStatement.cs Mon May  9 20:09:47 2005
@@ -289,7 +289,7 @@
 //					// to indicate the mapping order of the properties to the columns
 //					if (request.ParameterMap == null) // Inline Parameters
 //					{
-//						throw new DataMapperException("A procedure statement tag must alway have a parameterMap attribut, which is not the case for the procedure '"+_statement.Id+"'."); 
+//						throw new DataMapperException("A procedure statement tag must alway have a parameterMap attribute, which is not the case for the procedure '"+_statement.Id+"'."); 
 //					}
 //					else // Parameters via ParameterMap
 //					{
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/DomSqlMapBuilder.cs (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/DomSqlMapBuilder.cs Mon May  9 20:09:47 2005
@@ -401,11 +401,11 @@
 
 			_configScope.ErrorContext.Reset();
 
-			#region Resolve "resultMap" attribut on Result Property + initialize Discriminator property 
+			#region Resolve "resultMap" attribute on Result Property + initialize Discriminator property 
 
 			foreach(DictionaryEntry entry in _configScope.SqlMapper.ResultMaps)
 			{
-				_configScope.ErrorContext.Activity = "Resolve 'resultMap' attribut on Result Property";
+				_configScope.ErrorContext.Activity = "Resolve 'resultMap' attribute on Result Property";
 
 				ResultMap resultMap = (ResultMap)entry.Value;
 				foreach(DictionaryEntry item in resultMap.ColumnsToPropertiesMap)
@@ -1074,7 +1074,7 @@
 				//_configScope.ErrorContext.Resource = nodeProperties.InnerXml.ToString();
 				_configScope.ErrorContext.Resource = nodeProperties.OuterXml.ToString();
 
 				// Load the file defined by the resource attribut
 				XmlDocument propertiesConfig = Resources.GetAsXmlDocument(nodeProperties); 
 
 				foreach (XmlNode node in propertiesConfig.SelectNodes("/settings/add"))
@@ -1154,7 +1154,7 @@
 						}
 						else
 						{
-							throw new ConfigurationException("In mapping file '"+ _configScope.SqlMapNamespace +"' the parameterMap '"+parameterMap.Id+"' can not resolve extends attribut '"+parameterMap.ExtendMap+"'");
+							throw new ConfigurationException("In mapping file '"+ _configScope.SqlMapNamespace +"' the parameterMap '"+parameterMap.Id+"' can not resolve extends attribute '"+parameterMap.ExtendMap+"'");
 						}
 					}
 					else
@@ -1221,7 +1221,7 @@
 						}
 						else
 						{
-							throw new ConfigurationException("In mapping file '"+_configScope.SqlMapNamespace+"' the resultMap '"+resultMap.Id+"' can not resolve extends attribut '"+resultMap.ExtendMap+"'" );
+							throw new ConfigurationException("In mapping file '"+_configScope.SqlMapNamespace+"' the resultMap '"+resultMap.Id+"' can not resolve extends attribute '"+resultMap.ExtendMap+"'" );
 						}
 					}
 					else
@@ -1074,7 +1074,7 @@
 				_configScope.ErrorContext.Resource = nodeProperties.OuterXml.ToString();
 
-				// Load the file defined by the resource attribut
+				// Load the file defined by the resource attribute
 				XmlDocument propertiesConfig = Resources.GetAsXmlDocument(nodeProperties); 
 

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ParamaterMapping/ParameterMap.cs
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ParamaterMapping/ParameterMap.cs?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ParamaterMapping/ParameterProperty.cs (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ParamaterMapping/ParameterProperty.cs Mon May  9 20:09:47 2005
@@ -168,7 +168,7 @@
 		}
 
 		/// <summary>
 		/// The direction attribut of the XML parameter.
 		/// </summary>
 		/// <example> Input, Output, InputOutput</example>
 		[XmlAttribute("direction")]
@@ -204,7 +204,7 @@
 			set 
 			{ 
 				if ((value == null) || (value.Length < 1))
-					throw new ArgumentNullException("The property attribut is mandatory in a paremeter property.");
+					throw new ArgumentNullException("The property attribute is mandatory in a paremeter property.");
 
 				_property = value; 
 			}
@@ -168,7 +168,7 @@
 
 		/// <summary>
-		/// The direction attribut of the XML parameter.
+		/// The direction attribute of the XML parameter.
 		/// </summary>
 		/// <example> Input, Output, InputOutput</example>

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ResultMapping/ResultMap.cs
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/ResultMapping/ResultMap.cs?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================
--- incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/PreparedStatementFactory.cs (original)
+++ incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/PreparedStatementFactory.cs Mon May  9 20:09:47 2005
@@ -104,7 +104,7 @@
 			{
 				if (_request.ParameterMap == null) // No parameterMap --> error
 				{
-					throw new DataMapperException("A procedure statement tag must have a parameterMap attribut, which is not the case for the procedure '"+_statement.Id+"."); 
+					throw new DataMapperException("A procedure statement tag must have a parameterMap attribute, which is not the case for the procedure '"+_statement.Id+"."); 
 				}
 				else // use the parameterMap
 				{
@@ -221,7 +221,7 @@
 
 				IDataParameter dataParameter = _session.CreateCommand(_statement.CommandType).CreateParameter();
 
 				// Manage dbType attribut if any
 				if (property.DbType.Length >0) 
 				{
 					// Exemple : Enum.parse(System.Data.SqlDbType, 'VarChar')
@@ -304,7 +304,7 @@
 
 				IDataParameter dataParameter = _session.CreateCommand(_statement.CommandType).CreateParameter();
 
 				// Manage dbType attribut if any
 				if (property.DbType.Length >0) 
 				{
 					// Exemple : Enum.parse(System.Data.SqlDbType, 'VarChar')
@@ -221,7 +221,7 @@
 				IDataParameter dataParameter = _session.CreateCommand(_statement.CommandType).CreateParameter();
 
-				// Manage dbType attribut if any
+				// Manage dbType attribute if any
 				if (property.DbType.Length >0) 
 				{
@@ -304,7 +304,7 @@
 				IDataParameter dataParameter = _session.CreateCommand(_statement.CommandType).CreateParameter();
 
-				// Manage dbType attribut if any
+				// Manage dbType attribute if any
 				if (property.DbType.Length >0) 
 				{

Modified: incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/Procedure.cs
URL: http://svn.apache.org/viewcvs/incubator/ibatis/trunk/cs/mapper/IBatisNet.DataMapper/Configuration/Statements/Procedure.cs?rev=169402&r1=169401&r2=169402&view=diff
==============================================================================